# frozen_string_literal: true

require "faraday"
require "faraday_middleware"

module Outsmart
  class Client
    BASE_URL = "https://www.werkbonapp.nl/openapi/8"

    attr_reader :token, :software_token, :adapter

    def initialize(token:, software_token:, adapter: Faraday.default_adapter)
      @token = token
      @software_token = software_token
      @adapter = adapter
    end

    def connection
      @connection ||= Faraday.new do |conn|
        conn.url_prefix = BASE_URL
        conn.request :json
        conn.params[:token] = @token
        conn.params[:software_token] = @software_token
        conn.response :json, content_type: "application/json"
        conn.adapter adapter
      end
    end
  end
end
